@@ -23,11 +23,11 @@
 //! In the future, a concurrent BTree and HashTree will be added, that can be used inplace
 //! of a `RwLock<BTreeMap>` or `RwLock<HashMap>`. Stay tuned!
 
-// #![deny(warnings)]
-
+#![deny(warnings)]
 #![warn(unused_extern_crates)]
 #![warn(missing_docs)]
 #![allow(clippy::needless_lifetimes)]
+#![cfg_attr(feature = "simd_support", feature(portable_simd))]
 
 #[macro_use]
 extern crate smallvec;
@@ -43,10 +43,12 @@ pub mod cowcell;
 pub mod ebrcell;
 
 pub mod arcache;
+
 pub mod threadcache;
 
 pub mod bptree;
 pub mod hashmap;
+pub mod hashtrie;
 
 pub use cowcell::CowCell;
 pub use ebrcell::EbrCell;
